# Changelog

All notable changes to this project will be documented in this file.

This project adheres to Semantic Versioning.

## 1.2.0
- new tool `estimate_loyalty_points` - returns estimation of how many points a customer will earn for an order
- locked version for `fastmcp` dependency

## 1.1.0
- get_best_deals: add applicability flag and discounted cart preview

## 1.0.0
- First version of the MCP server


